# Python Markdown Extension: typehint

An extension for [Python-Markdown](https://python-markdown.github.io). Replaces `[@TYPENAME]` text with styled "bubble" with a unique color.

## Example Output

<p><span style="background:#6A0DAD;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Any</span>
<span style="background:#F90;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Array</span>
<span style="background:#000;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Boolean</span>
<span style="background:#F1C40F;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Class</span>
<span style="background:#FFC0CB;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Date</span>
<span style="background:#95BD42;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Element</span>
<span style="background:#BDC581;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Float</span>
<span style="background:#008000;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Function</span>
<span style="background:#3F42BD;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Int</span>
<span style="background:#BD3F42;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Number</span>
<span style="background:#999;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">Object</span>
<span style="background:#D35400;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">RegExp</span>
<span style="background:#3A87AD;display:inline-block;padding:.4em .6em;font-size:75%;font-weight:700;line-height:1;color:#FFF;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em;">String</span></p>